@@ -13,6 +13,7 @@ import time
 import os
 import uuid
 import warnings
+import base64
 import Pyro4.futures
 from Pyro4 import errors, threadutil, socketutil, util, constants, message
 from Pyro4.socketserver.threadpoolserver import SocketServer_Threadpool
@@ -168,7 +169,7 @@ class _RemoteMethod(object):
         return self.__send(self.__name, args, kwargs)
 
 
-def _check_hmac():
+def _check_hmac():      # deprecated, HMAC_KEY will be removed in next version
     if Pyro4.config.HMAC_KEY:
         if sys.version_info >= (3, 0) and type(Pyro4.config.HMAC_KEY) is not bytes:
             raise errors.PyroError("HMAC_KEY must be bytes type")
@@ -185,13 +186,12 @@ class Proxy(object):
     .. automethod:: _pyroAsync
     """
     __pyroAttributes = frozenset(
-        ["__getnewargs__", "__getnewargs_ex__", "__getinitargs__", "_pyroConnection", "_pyroUri", "_pyroOneway",
-         "_pyroMethods", "_pyroAttrs", "_pyroTimeout", "_pyroSeq",
+        ["__getnewargs__", "__getnewargs_ex__", "__getinitargs__", "_pyroConnection", "_pyroUri",
+         "_pyroOneway", "_pyroMethods", "_pyroAttrs", "_pyroTimeout", "_pyroSeq", "_pyroHmacKey",
          "_Proxy__pyroTimeout", "_Proxy__pyroLock", "_Proxy__pyroConnLock"])
 
     def __init__(self, uri):
         """
-        .. autoattribute:: _pyroOneway
         .. autoattribute:: _pyroTimeout
         """
         _check_hmac()  # check if hmac secret key is set
@@ -203,18 +203,15 @@ class Proxy(object):
         self._pyroConnection = None
         self._pyroMethods = set()  # all methods of the remote object, gotten from meta-data
         self._pyroAttrs = set()  # attributes of the remote object, gotten from meta-data
-        self._pyroOneway = set()  # oneway-methods of the remote object, gotten from meta-data (or set by user, that's deprecated though.)
+        self._pyroOneway = set()  # oneway-methods of the remote object, gotten from meta-data
         self._pyroSeq = 0  # message sequence number
+        self._pyroHmacKey = Pyro4.config.HMAC_KEY
         self.__pyroTimeout = Pyro4.config.COMMTIMEOUT
         self.__pyroLock = threadutil.Lock()
         self.__pyroConnLock = threadutil.Lock()
         util.get_serializer(Pyro4.config.SERIALIZER)  # assert that the configured serializer is available
         if os.name == "java" and Pyro4.config.SERIALIZER == "marshal":
             warnings.warn("marshal doesn't work correctly with Jython (issue 2077); please choose another serializer", RuntimeWarning)
-        if Pyro4.config.DOTTEDNAMES:
-            warnings.warn("DOTTEDNAMES is deprecated and it will be removed in the next version", DeprecationWarning)
-            if Pyro4.config.METADATA:
-                warnings.warn("DOTTEDNAMES and METADATA are both enabled, DOTTEDNAMES doesn't really work in this situation", RuntimeWarning)
 
     def __del__(self):
         if hasattr(self, "_pyroConnection"):
@@ -255,7 +252,14 @@ class Proxy(object):
         return str(self)
 
     def __getstate_for_dict__(self):
-        return self._pyroUri.asString(), tuple(self._pyroOneway), tuple(self._pyroMethods), tuple(self._pyroAttrs), self.__pyroTimeout
+        encodedHmac = None
+        if self._pyroHmacKey is not None:
+            if sys.platform == 'cli' and type(self._pyroHmacKey) is bytes:
+                # ironpython doesn't grok bytes for b64encode
+                self._pyroHmacKey = str(self._pyroHmacKey)
+            encodedHmac = "b64:"+(base64.b64encode(self._pyroHmacKey).decode("ascii"))
+        return self._pyroUri.asString(), tuple(self._pyroOneway), tuple(self._pyroMethods), tuple(self._pyroAttrs),\
+            self.__pyroTimeout, encodedHmac
 
     def __setstate_from_dict__(self, state):
         uri = URI(state[0])
@@ -263,13 +267,19 @@ class Proxy(object):
         methods = set(state[2])
         attrs = set(state[3])
         timeout = state[4]
-        self.__setstate__((uri, oneway, methods, attrs, timeout))
+        hmac_key = state[5]
+        if hmac_key:
+            if hmac_key.startswith("b64:"):
+                hmac_key = base64.b64decode(hmac_key[4:].encode("ascii"))
+            else:
+                raise errors.ProtocolError("hmac encoding error")
+        self.__setstate__((uri, oneway, methods, attrs, timeout, hmac_key))
 
     def __getstate__(self):
-        return self._pyroUri, self._pyroOneway, self._pyroMethods, self._pyroAttrs, self.__pyroTimeout  # skip the connection
+        return self._pyroUri, self._pyroOneway, self._pyroMethods, self._pyroAttrs, self.__pyroTimeout, self._pyroHmacKey  # skip the connection
 
     def __setstate__(self, state):
-        self._pyroUri, self._pyroOneway, self._pyroMethods, self._pyroAttrs, self.__pyroTimeout = state
+        self._pyroUri, self._pyroOneway, self._pyroMethods, self._pyroAttrs, self.__pyroTimeout, self._pyroHmacKey = state
         self._pyroConnection = None
         self._pyroSeq = 0
         self.__pyroLock = threadutil.Lock()
@@ -282,6 +292,7 @@ class Proxy(object):
         p._pyroMethods = set(self._pyroMethods)
         p._pyroAttrs = set(self._pyroAttrs)
         p._pyroTimeout = self._pyroTimeout
+        p._pyroHmacKey = self._pyroHmacKey
         return p
 
     def __enter__(self):
@@ -351,14 +362,14 @@ class Proxy(object):
             if Pyro4.config.LOGWIRE:
                 log.debug("proxy wiredata sending: msgtype=%d flags=0x%x ser=%d seq=%d data=%r" %
                           (message.MSG_INVOKE, flags, serializer.serializer_id, self._pyroSeq, data))
-            msg = message.Message(message.MSG_INVOKE, data, serializer.serializer_id, flags, self._pyroSeq)
+            msg = message.Message(message.MSG_INVOKE, data, serializer.serializer_id, flags, self._pyroSeq, hmac_key=self._pyroHmacKey)
             try:
                 self._pyroConnection.send(msg.to_bytes())
                 del msg  # invite GC to collect the object, don't wait for out-of-scope
                 if flags & message.FLAGS_ONEWAY:
                     return None  # oneway call, no response data
                 else:
-                    msg = message.Message.recv(self._pyroConnection, [message.MSG_RESULT])
+                    msg = message.Message.recv(self._pyroConnection, [message.MSG_RESULT], hmac_key=self._pyroHmacKey)
                     if Pyro4.config.LOGWIRE:
                         log.debug("proxy wiredata received: msgtype=%d flags=0x%x ser=%d seq=%d data=%r" % (msg.type, msg.flags, msg.serializer_id, msg.seq, msg.data))
                     self.__pyroCheckSequence(msg.seq)
@@ -446,7 +457,6 @@ class Proxy(object):
             if Pyro4.config.METADATA:
                 # obtain metadata if this feature is enabled, and the metadata is not known yet
                 if self._pyroMethods or self._pyroAttrs:
-                    # not checking _pyroOneway because that feature already existed and people are already modifying it on the proxy
                     log.debug("reusing existing metadata")
                 else:
                     self._pyroGetMetadata(uri.object)
@@ -457,21 +467,17 @@ class Proxy(object):
         objectId = objectId or self._pyroUri.object
         log.debug("getting metadata for object %s", objectId)
         if self._pyroConnection is None and not known_metadata:
-            self.__pyroCreateConnection()
+            try:
+                self.__pyroCreateConnection()
+            except errors.PyroError:
+                log.error("problem getting metadata: cannot connect")
+                raise
             if self._pyroMethods or self._pyroAttrs:
                 return  # metadata has already been retrieved as part of creating the connection
         try:
-            user_specified_oneways = self._pyroOneway   # possible old client code writes to _pyroOneway instead of relying on metadata
             # invoke the get_metadata method on the daemon
             result = known_metadata or self._pyroInvoke("get_metadata", [objectId], {}, objectId=constants.DAEMON_NAME)
-            meta_oneways = set(result["oneway"])
-            if not user_specified_oneways.issubset(meta_oneways):
-                msg = "metadata oneway differs from code, forgot @Pyro4.oneway on the server method(s)? objectId=%s\n" \
-                      "user-specified: %s  metadata from server: %s" % (objectId, user_specified_oneways, meta_oneways)
-                log.warning(msg)
-                warnings.warn(msg, UserWarning)
-                warnings.warn("setting _pyroOneway yourself is deprecated and support for that will be dropped in the next version", DeprecationWarning)
-            self._pyroOneway = meta_oneways | user_specified_oneways  # merge the old oneway stuff with the info we got from the metadata
+            self._pyroOneway = set(result["oneway"])
             self._pyroMethods = set(result["methods"])
             self._pyroAttrs = set(result["attrs"])
             if log.isEnabledFor(logging.DEBUG):
@@ -905,7 +911,7 @@ class Daemon(object):
                     # batched method calls, loop over them all and collect all results
                     data = []
                     for method, vargs, kwargs in vargs:
-                        method = util.resolveDottedAttribute(obj, method, Pyro4.config.DOTTEDNAMES)
+                        method = util.getAttribute(obj, method)
                         try:
                             result = method(*vargs, **kwargs)  # this is the actual method call to the Pyro object
                         except Exception:
@@ -928,7 +934,7 @@ class Daemon(object):
                         # special case for direct attribute access (only exposed @properties are accessible)
                         data = util.set_exposed_property_value(obj, vargs[0], vargs[1], only_exposed=Pyro4.config.REQUIRE_EXPOSE)
                     else:
-                        method = util.resolveDottedAttribute(obj, method, Pyro4.config.DOTTEDNAMES)
+                        method = util.getAttribute(obj, method)
                         if request_flags & Pyro4.message.FLAGS_ONEWAY and Pyro4.config.ONEWAY_THREADED:
                             # oneway call to be run inside its own thread
                             thread = threadutil.Thread(target=method, args=vargs, kwargs=kwargs)
