@@ -4,35 +4,45 @@ Socket server based on socket multiplexing. Doesn't use threads.
 Pyro - Python Remote Objects.  Copyright by Irmen de Jong (irmen@razorvine.net).
 """
 
-import socket, select, sys, logging, os
+from __future__ import with_statement, print_function
+import socket
+import select
+import sys
+import logging
+import os
 from Pyro4 import socketutil, errors, util
-import Pyro4
+import Pyro4.constants
 
-log=logging.getLogger("Pyro4.socketserver.multiplexed")
+log = logging.getLogger("Pyro4.multiplexserver")
 
 
 class MultiplexedSocketServerBase(object):
     """base class for multiplexed transport server for socket connections"""
+
+    def __init__(self):
+        self.sock = self.daemon = self.locationStr = None
+        self.clients = set()
+
     def init(self, daemon, host, port, unixsocket=None):
         log.info("starting multiplexed socketserver")
-        self.sock=None
-        bind_location=unixsocket if unixsocket else (host, port)
-        self.sock=socketutil.createSocket(bind=bind_location, reuseaddr=Pyro4.config.SOCK_REUSE, timeout=Pyro4.config.COMMTIMEOUT, noinherit=True)
-        self.clients=set()
-        self.daemon=daemon
-        sockaddr=self.sock.getsockname()
-        if sockaddr[0].startswith("127."):
-            if host is None or host.lower()!="localhost" and not host.startswith("127."):
+        self.sock = None
+        bind_location = unixsocket if unixsocket else (host, port)
+        self.sock = socketutil.createSocket(bind=bind_location, reuseaddr=Pyro4.config.SOCK_REUSE, timeout=Pyro4.config.COMMTIMEOUT, noinherit=True)
+        self.clients = set()
+        self.daemon = daemon
+        sockaddr = self.sock.getsockname()
+        if not unixsocket and sockaddr[0].startswith("127."):
+            if host is None or host.lower() != "localhost" and not host.startswith("127."):
                 log.warning("weird DNS setup: %s resolves to localhost (127.x.x.x)", host)
         if unixsocket:
-            self.locationStr="./u:"+unixsocket
+            self.locationStr = "./u:" + unixsocket
         else:
-            host=host or sockaddr[0]
-            port=port or sockaddr[1]
-            if ":" in host:   # ipv6
-                self.locationStr="[%s]:%d" % (host, port)
+            host = host or sockaddr[0]
+            port = port or sockaddr[1]
+            if ":" in host:  # ipv6
+                self.locationStr = "[%s]:%d" % (host, port)
             else:
-                self.locationStr="%s:%d" % (host, port)
+                self.locationStr = "%s:%d" % (host, port)
 
     def __repr__(self):
         return "<%s on %s, %d connections>" % (self.__class__.__name__, self.locationStr, len(self.clients))
@@ -40,14 +50,14 @@ class MultiplexedSocketServerBase(object):
     def __del__(self):
         if self.sock is not None:
             self.sock.close()
-            self.sock=None
+            self.sock = None
 
     def events(self, eventsockets):
         """used for external event loops: handle events that occur on one of the sockets of this server"""
         for s in eventsockets:
             if s is self.sock:
                 # server socket, means new connection
-                conn=self._handleConnection(self.sock)
+                conn = self._handleConnection(self.sock)
                 if conn:
                     self.clients.add(conn)
             else:
@@ -65,8 +75,8 @@ class MultiplexedSocketServerBase(object):
             if Pyro4.config.COMMTIMEOUT:
                 csock.settimeout(Pyro4.config.COMMTIMEOUT)
         except socket.error:
-            x=sys.exc_info()[1]
-            err=getattr(x, "errno", x.args[0])
+            x = sys.exc_info()[1]
+            err = getattr(x, "errno", x.args[0])
             if err in socketutil.ERRNO_RETRIES:
                 # just ignore this error for now and continue
                 log.warning("accept() failed errno=%d, shouldn't happen", err)
@@ -76,10 +86,10 @@ class MultiplexedSocketServerBase(object):
                 raise errors.ConnectionClosedError("server socket closed")
             raise
         try:
-            conn=socketutil.SocketConnection(csock)
+            conn = socketutil.SocketConnection(csock)
             if self.daemon._handshake(conn):
                 return conn
-        except:     # catch all errors, otherwise the event loop could terminate
+        except:  # catch all errors, otherwise the event loop could terminate
             ex_t, ex_v, ex_tb = sys.exc_info()
             tb = util.formatTraceback(ex_t, ex_v, ex_tb)
             log.warning("error during connect/handshake: %s; %s", ex_v, "\n".join(tb))
@@ -93,9 +103,9 @@ class MultiplexedSocketServerBase(object):
     def close(self):
         log.debug("closing socketserver")
         if self.sock:
-            sockname=None
+            sockname = None
             try:
-                sockname=self.sock.getsockname()
+                sockname = self.sock.getsockname()
             except socket.error:
                 pass
             self.sock.close()
@@ -103,17 +113,17 @@ class MultiplexedSocketServerBase(object):
                 # it was a Unix domain socket, remove it from the filesystem
                 if os.path.exists(sockname):
                     os.remove(sockname)
-        self.sock=None
+        self.sock = None
         for c in self.clients:
             try:
                 c.close()
             except Exception:
                 pass
-        self.clients=set()
+        self.clients = set()
 
     @property
     def sockets(self):
-        socks=[self.sock]
+        socks = [self.sock]
         socks.extend(self.clients)
         return socks
 
@@ -134,7 +144,8 @@ class MultiplexedSocketServerBase(object):
             # other error occurred, close the connection, but also log a warning
             ex_t, ex_v, ex_tb = sys.exc_info()
             tb = util.formatTraceback(ex_t, ex_v, ex_tb)
-            log.warning("error during handleRequest: %s; %s", ex_v, "\n".join(tb))
+            msg = "error during handleRequest: %s; %s" % (ex_v, "".join(tb))
+            log.warning(msg)
             return False
 
 
@@ -143,28 +154,28 @@ class SocketServer_Poll(MultiplexedSocketServerBase):
 
     def loop(self, loopCondition=lambda: True):
         log.debug("enter poll-based requestloop")
-        poll=select.poll()
+        poll = select.poll()
         try:
-            fileno2connection={}  # map fd to original connection object
-            rlist=list(self.clients)+[self.sock]
+            fileno2connection = {}  # map fd to original connection object
+            rlist = list(self.clients) + [self.sock]
             for r in rlist:
                 poll.register(r.fileno(), select.POLLIN | select.POLLPRI)
-                fileno2connection[r.fileno()]=r
+                fileno2connection[r.fileno()] = r
             while loopCondition():
-                polls=poll.poll(1000*Pyro4.config.POLLTIMEOUT)
+                polls = poll.poll(1000 * Pyro4.config.POLLTIMEOUT)
                 for (fd, mask) in polls:
-                    conn=fileno2connection[fd]
+                    conn = fileno2connection[fd]
                     if conn is self.sock:
-                        conn=self._handleConnection(self.sock)
+                        conn = self._handleConnection(self.sock)
                         if conn:
                             poll.register(conn.fileno(), select.POLLIN | select.POLLPRI)
-                            fileno2connection[conn.fileno()]=conn
+                            fileno2connection[conn.fileno()] = conn
                             self.clients.add(conn)
                     else:
                         active = self.handleRequest(conn)
                         if not active:
                             try:
-                                fn=conn.fileno()
+                                fn = conn.fileno()
                             except socket.error:
                                 pass
                             else:
@@ -189,7 +200,7 @@ class SocketServer_Select(MultiplexedSocketServerBase):
         log.debug("entering select-based requestloop")
         while loopCondition():
             try:
-                rlist=list(self.clients)
+                rlist = list(self.clients)
                 rlist.append(self.sock)
                 try:
                     rlist, _, _ = socketutil.selectfunction(rlist, [], [], Pyro4.config.POLLTIMEOUT)
@@ -205,7 +216,7 @@ class SocketServer_Select(MultiplexedSocketServerBase):
                         rlist.remove(self.sock)
                     except ValueError:
                         pass  # this can occur when closing down, even when we just tested for presence in the list
-                    conn=self._handleConnection(self.sock)
+                    conn = self._handleConnection(self.sock)
                     if conn:
                         self.clients.add(conn)
                 for conn in rlist:
@@ -216,7 +227,7 @@ class SocketServer_Select(MultiplexedSocketServerBase):
                             conn.close()
                             self.clients.discard(conn)
             except socket.timeout:
-                pass   # just continue the loop on a timeout
+                pass  # just continue the loop on a timeout
             except KeyboardInterrupt:
                 log.debug("stopping on break signal")
                 break
