@@ -315,6 +315,7 @@ class CoreTests(unittest.TestCase):
         p1._pyroTimeout = 42
         p1._pyroOneway = set("def")
         p1._pyroMethods = set("ghi")
+        p1._pyroHmacKey = b"secret"
         p2 = copy.copy(p1)
         self.assertEqual(p1, p2)
         self.assertEqual(p1._pyroUri, p2._pyroUri)
@@ -322,6 +323,7 @@ class CoreTests(unittest.TestCase):
         self.assertEqual(p1._pyroMethods, p2._pyroMethods)
         self.assertEqual(p1._pyroAttrs, p2._pyroAttrs)
         self.assertEqual(p1._pyroTimeout, p2._pyroTimeout)
+        self.assertEqual(p1._pyroHmacKey, p2._pyroHmacKey)
 
     def testProxyOffline(self):
         # only offline stuff here.
@@ -434,6 +436,47 @@ class CoreTests(unittest.TestCase):
         with p:
             self.assertIsNotNone(p._pyroUri)
 
+    def testProxyHmac(self):
+        class ConnectionMock(object):
+            def __int__(self):
+                self.msgbytes = None
+            def close(self):
+                pass
+            def send(self, msgbytes):
+                self.msgbytes = msgbytes
+            def recv(self, size):
+                raise Pyro4.errors.ConnectionClosedError("mock")
+        proxy = Pyro4.core.Proxy("PYRO:foobar@localhost:59999")
+        self.assertEqual(b"testsuite", proxy._pyroHmacKey)  # set by (deprecated) HMAC_KEY config item
+        proxy._pyroHmacKey = b"secret"
+        conn_mock = ConnectionMock()
+        proxy._pyroConnection = conn_mock
+        with self.assertRaises(Pyro4.errors.ConnectionClosedError):
+            proxy.foo()
+        if sys.platform == 'cli':
+            self.assertIn("HMAC", conn_mock.msgbytes)
+        else:
+            self.assertIn(b"HMAC", conn_mock.msgbytes)
+
+        conn_mock = ConnectionMock()
+        proxy._pyroConnection = conn_mock
+        proxy._pyroHmacKey = None
+        with self.assertRaises(Pyro4.errors.ConnectionClosedError):
+            proxy.foo()
+        if sys.platform == 'cli':
+            self.assertIn("HMAC", conn_mock.msgbytes)   # (deprecated) HMAC_KEY is still set
+        else:
+            self.assertIn(b"HMAC", conn_mock.msgbytes)   # (deprecated) HMAC_KEY is still set
+        self.assertIsNone(proxy._pyroHmacKey)
+        Pyro4.config.HMAC_KEY = None
+        conn_mock = ConnectionMock()
+        proxy._pyroConnection = conn_mock
+        proxy._pyroHmacKey = None
+        with self.assertRaises(Pyro4.errors.ConnectionClosedError):
+            proxy.foo()
+        self.assertNotIn(b"HMAC", conn_mock.msgbytes)
+        self.assertIsNone(proxy._pyroHmacKey)
+
     def testNoConnect(self):
         wrongUri = Pyro4.core.URI("PYRO:foobar@localhost:59999")
         with Pyro4.core.Proxy(wrongUri) as p:
@@ -751,6 +794,13 @@ def crashingfuturestestfunc(a):
     return 1 // 0  # crash
 
 
+class FuturesErrorHandlerStorage(object):
+    def __init__(self):
+        self.error = None
+    def errorhandler(self, err):
+        self.error = err
+
+
 class TestFutures(unittest.TestCase):
     def testSimpleFuture(self):
         f = Pyro4.Future(futurestestfunc)
@@ -760,18 +810,20 @@ class TestFutures(unittest.TestCase):
         self.assertEqual(9, value)
 
     def testFutureChain(self):
-        f = Pyro4.Future(futurestestfunc)
-        f.then(futurestestfunc, 6)
-        f.then(futurestestfunc, 7, extra=10)
+        f = Pyro4.Future(futurestestfunc) \
+            .then(futurestestfunc, 6) \
+            .then(futurestestfunc, 7) \
+            .then(futurestestfunc, 8) \
+            .then(futurestestfunc, 9, extra=10)
         r = f(4, 5)
         value = r.value
-        self.assertEqual(4 + 5 + 6 + 7 + 10, value)
+        self.assertEqual(4 + 5 + 6 + 7 + 8 + 9 + 10, value)
 
     def testCrashingChain(self):
-        f = Pyro4.Future(futurestestfunc)
-        f.then(futurestestfunc, 6)
-        f.then(crashingfuturestestfunc)
-        f.then(futurestestfunc, 8)
+        f = Pyro4.Future(futurestestfunc) \
+            .then(futurestestfunc, 6) \
+            .then(crashingfuturestestfunc) \
+            .then(futurestestfunc, 8)
         r = f(4, 5)
         try:
             _ = r.value
@@ -779,6 +831,43 @@ class TestFutures(unittest.TestCase):
         except ZeroDivisionError:
             pass  # ok
 
+    def testErrorHandler(self):
+        storage = FuturesErrorHandlerStorage()
+        f = Pyro4.Future(crashingfuturestestfunc) \
+            .then(futurestestfunc, 5) \
+            .iferror(storage.errorhandler) \
+            .then(futurestestfunc, 6)
+        self.assertIsNone(storage.error)
+        r = f(42)
+        try:
+            _ = r.value
+        except ZeroDivisionError:
+            pass  # ok
+        self.assertIsInstance(storage.error, ZeroDivisionError)
+
+    def testFutureResultChainSlow(self):
+        f = Pyro4.Future(futurestestfunc)
+        result = f(4, 5)
+        time.sleep(.02)
+        result.then(futurestestfunc, 6)
+        time.sleep(.02)
+        result.then(futurestestfunc, 7)
+        time.sleep(.02)
+        result.then(futurestestfunc, 8)
+        time.sleep(.02)
+        result.then(futurestestfunc, 9)
+        time.sleep(.02)
+        result.then(futurestestfunc, 10)
+        time.sleep(.02)
+        value = result.value
+        self.assertEqual(4 + 5 + 6 + 7 + 8 + 9 + 10, value)
+
+    def testFutureResultChain(self):
+        f = Pyro4.Future(futurestestfunc)
+        result = f(4, 5).then(futurestestfunc, 6).then(futurestestfunc, 7).then(futurestestfunc, 8).then(futurestestfunc, 9).then(futurestestfunc, 10)
+        value = result.value
+        self.assertEqual(4 + 5 + 6 + 7 + 8 + 9 + 10, value)
+
 
 if __name__ == "__main__":
     # import sys;sys.argv = ['', 'Test.testName']
